'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.BorderedMessage = undefined;

var _chalk = require('chalk');

var _chalk2 = _interopRequireDefault(_chalk);

var _BaseMessage = require('./BaseMessage');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) arr2[i] = arr[i]; return arr2; } else { return Array.from(arr); } }

/**
 * Class responsible for printing out bordered messages
 *
 * @since 2.0.0
 * @version 2.0.0
 */
class BorderedMessage extends _BaseMessage.BaseMessage {
  constructor(lines, config) {
    super(lines, config);

    this.setConfig({
      borderColor: 'yellow',
      borderSymbol: '─',
      sideSymbol: '│',
      leftTopSymbol: '┌',
      leftBottomSymbol: '└',
      rightTopSymbol: '┐',
      rightBottomSymbol: '┘',
      paddingTop: 0,
      paddingBottom: 0
    }).setConfig(config);
  }

  /**
   * Makes bordered message.
   *
   * @returns {String}
   */
  toString() {
    var _Math;

    let lines = this.getLines();
    let config = this.getConfig();
    let maxWidth = (_Math = Math).max.apply(_Math, _toConsumableArray(lines.map(line => _BaseMessage.BaseMessage.getTextLength(line))));

    if (config.color !== 'default' && !_chalk2.default[config.color]) throw new Error(`Color ${ config.color } is not supported`);
    if (config.borderColor !== 'default' && !_chalk2.default[config.borderColor]) throw new Error(`Color ${ config.borderColor } is not supported`);

    let topBorder = _chalk2.default[config.borderColor](config.leftTopSymbol + config.borderSymbol.repeat(maxWidth) + config.rightTopSymbol);
    let sideSeparator = _chalk2.default[config.borderColor](config.sideSymbol);
    let bottomBorder = _chalk2.default[config.borderColor](config.leftBottomSymbol + config.borderSymbol.repeat(maxWidth) + config.rightBottomSymbol);

    return ['\n'.repeat(config.marginTop), topBorder + '\n', (sideSeparator + ' '.repeat(maxWidth) + sideSeparator + '\n').repeat(config.paddingTop), lines.reduce((message, line) => message + sideSeparator + (config.color !== 'default' ? _chalk2.default[config.color](line) : line) + ' '.repeat(maxWidth - _BaseMessage.BaseMessage.getTextLength(line)) + sideSeparator + '\n', ''), (sideSeparator + ' '.repeat(maxWidth) + sideSeparator + '\n').repeat(config.paddingBottom), bottomBorder + '\n', '\n'.repeat(config.marginBottom)].join('');
  }
}
exports.BorderedMessage = BorderedMessage;